import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { TagEnum } from '../../enum/tag.enum';
import { Tag } from '../../models/tag.model';
import { TagWithMeta } from '../../models/tagWithMeta.model';
import { parseSlugToTag } from '../utils/NewsUtils';
@Component({
  selector: 'app-post-header',
  templateUrl: './post-header.component.html',
  styleUrls: ['./post-header.component.scss'],
})
export class PostHeaderComponent implements OnInit {
  public tags: TagWithMeta;
  public mainActiveTag: Tag = new Tag({ slug: TagEnum.aLaUne });
  public tagEnum = TagEnum;

  public checkedPublicTags: Tag[] = [];
  public checkedLocationTags: Tag[] = [];

  constructor(
    private route: ActivatedRoute,
    private router: Router,
  ) {}

  ngOnInit(): void {
    this.route.data.subscribe((data) => {
      if (data.tags) {
        this.tags = data.tags;
        this.removeTagBySlug(TagEnum.aLaUneSection);
        this.updateTagName(TagEnum.aLaUne, 'Les + récentes');
        this.sortTagsByName(this.tags.commune);
      }
    });

    this.route.queryParams.subscribe((queryParams) => {
      if (queryParams.mainTag) {
        this.mainActiveTag = new Tag({ slug: queryParams.mainTag });
      }
      if (queryParams.publicTags) {
        this.checkedPublicTags = parseSlugToTag(queryParams.publicTags);
      }
      if (queryParams.locationTags) {
        this.checkedLocationTags = parseSlugToTag(queryParams.locationTags);
      }
    });
  }

  private removeTagBySlug(slugToRemove: string): void {
    this.tags.others = this.tags.others.filter((tag) => tag.slug !== slugToRemove);
  }

  private updateTagName(slugToUpdate: string, newName: string): void {
    this.tags.others.forEach((tag) => {
      if (tag.slug === slugToUpdate) {
        tag.name = newName;
      }
    });
  }

  private sortTagsByName(tags: Tag[]): void {
    tags.sort((tagA, tagB) => this.sortArray(tagA, tagB));
  }

  private sortArray(tagA: Tag, tagB: Tag): number {
    const nameTagA = tagA.name.toUpperCase();
    const nameTagB = tagB.name.toUpperCase();
    return nameTagA.localeCompare(nameTagB);
  }

  public activateTag(tag: Tag): void {
    this.mainActiveTag = tag;
    this.setQueryParam();
  }

  private setQueryParam(): void {
    this.router.navigate(['/news'], {
      relativeTo: this.route,
      queryParams: {
        mainTag: this.getMainTag(),
        publicTags: this.checkedPublicTags.map((tag) => tag.slug),
        locationTags: this.checkedLocationTags.map((tag) => tag.slug),
      },
      queryParamsHandling: 'merge',
    });
  }

  public getMainTag(): string {
    if (this.mainActiveTag.slug === TagEnum.aLaUne) {
      return '';
    }
    return this.mainActiveTag.slug === this.tagEnum.etudes ? this.mainActiveTag.name : this.mainActiveTag.slug;
  }

  public togglePublishNews(): void {
    this.router.navigate(['publish'], { relativeTo: this.route });
  }
}
