import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { StructureType } from '../../../models/structureType.model';
import { StructureTypeService } from '../../../services/structure-type.service';
import { StructureCategoryEnum } from '../../enum/structureCategory.enum';
import { ButtonType } from '../button/buttonType.enum';

@Component({
  selector: 'app-structure-type-picker',
  templateUrl: './structure-type-picker.component.html',
})
export class StructureTypePickerComponent implements OnInit {
  public publicTypes: StructureType[];
  public privateTypes: StructureType[];
  public privateLucrativeTypes: StructureType[];
  @Input() public pickedTypeId?: string;
  @Output() selectedType: EventEmitter<string> = new EventEmitter<string>();

  public buttonTypeEnum = ButtonType;
  public structureTypeCategoryEnum = StructureCategoryEnum;

  constructor(private structureTypeService: StructureTypeService) {}

  ngOnInit(): void {
    this.structureTypeService.getStructureTypes().subscribe((types) => {
      // Filter "other" structure type
      types = types.filter((type) => type.selectable);
      types = types.sort((a, b) => a.name.localeCompare(b.name));
      this.publicTypes = types.filter((type) => type.category === this.structureTypeCategoryEnum.public);
      this.privateTypes = types.filter((type) => type.category === this.structureTypeCategoryEnum.private);
      this.privateLucrativeTypes = types.filter(
        (type) => type.category === this.structureTypeCategoryEnum.privateLucrative,
      );
    });
  }

  public pickStructureType(structureTypeId: string): void {
    this.pickedTypeId = structureTypeId;
    this.selectedType.emit(structureTypeId);
  }
}
