import { Component, EventEmitter, Input, Output } from '@angular/core';
import { SpriteFolderType } from '../../../svg-icon/SpriteFolder.type';
import { ButtonTypeV3 } from '../button.component';

@Component({
  selector: 'app-v3-icon-button',
  templateUrl: './icon-button.component.html',
  styleUrls: ['../button.component.scss'],
})
export class IconButtonV3Component {
  /** Icon name */
  @Input({ required: true }) iconName: string;

  /** HTML type of the button */
  @Input() type: 'submit' | 'button' | 'reset' = 'button';

  /** What variant should the button be ? */
  @Input({ required: true }) variant: ButtonTypeV3;

  /** Affects the height of the button */
  @Input() size?: 'small' | 'medium' = 'small';

  /** Should the button be disabled ? */
  @Input() disabled = false;

  /** Folder of the sprite ex: assets/ico/sprite.svg */
  @Input() iconFolder: SpriteFolderType = 'ico';

  /** Icon color, defaults to none as the svg-icon does */
  @Input() iconColor = 'none';

  /** Click handler */
  @Output() action = new EventEmitter<Event>();

  public get classes(): string[] {
    return ['icon-only', this.variant, this.size];
  }
}
